Author: duncan
Date: Fri Oct  6 22:25:10 2006
New Revision: 8332

Modified:
   branches/rel-1-5/freevo/src/plugins/upsoon.py

Log:
Changed reporting time it was confusing

Modified: branches/rel-1-5/freevo/src/plugins/upsoon.py
==============================================================================
--- branches/rel-1-5/freevo/src/plugins/upsoon.py       (original)
+++ branches/rel-1-5/freevo/src/plugins/upsoon.py       Fri Oct  6 22:25:10 2006
@@ -92,6 +92,7 @@
         _debug_('up=%s %s' % (self.serverup, self.next_program), dbglvl)
 
         self.fc = FreevoChannels()
+        self.seconds_before_start = 90
 
 
     def findNextProgram(self):
@@ -185,10 +186,10 @@
         if self.next_program == None:
             return None
 
-        secs_to_next = int(self.next_program.start - now + 0.5)
+        secs_to_next = self.next_program.start - config.TV_RECORD_PADDING_PRE 
- int(now + 0.5)
         _debug_('next recording in %s secs' % (secs_to_next), dbglvl)
-        # stop the player 60 seconds before recording is due to start
-        if (secs_to_next > config.TV_RECORD_PADDING_PRE+60):
+        # stop the player 90 seconds before recording is due to start
+        if (secs_to_next > self.seconds_before_start):
             return None
 
         _debug_('recording in less that a minute (%s secs)' % (secs_to_next), 
dbglvl)

-------------------------------------------------------------------------
Take Surveys. Earn Cash. Influence the Future of IT
Join SourceForge.net's Techsay panel and you'll get the chance to share your
opinions on IT & business topics through brief surveys -- and earn cash
http://www.techsay.com/default.php?page=join.php&p=sourceforge&CID=DEVDEV
_______________________________________________
Freevo-cvslog mailing list
[email protected]
https://lists.sourceforge.net/lists/listinfo/freevo-cvslog

Reply via email to